==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HttpSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HttpSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The configuration settings of the HTTP requests for authentication and authorization requests made against ContainerApp Service Authentication/Authorization.
 * @property forwardProxy The configuration settings of a forward proxy used to make the requests.
 * @property requireHttps <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
 * @property routes The configuration settings of the paths HTTP requests.
 */
public data class HttpSettingsArgs(
    public val forwardProxy: Output<ForwardProxyArgs>? = null,
    public val requireHttps: Output<Boolean>? = null,
    public val routes: Output<HttpSettingsRoutesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HttpSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HttpSettingsArgs =
        com.pulumi.azurenative.app.inputs.HttpSettingsArgs.builder()
            .forwardProxy(forwardProxy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .requireHttps(requireHttps?.applyValue({ args0 -> args0 }))
            .routes(routes?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [HttpSettingsArgs].
 */
@PulumiTagMarker
public class HttpSettingsArgsBuilder internal constructor() {
    private var forwardProxy: Output<ForwardProxyArgs>? = null

    private var requireHttps: Output<Boolean>? = null

    private var routes: Output<HttpSettingsRoutesArgs>? = null

    /**
     * @param value The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("vwtcvwkfgihqwamm")
    public suspend fun forwardProxy(`value`: Output<ForwardProxyArgs>) {
        this.forwardProxy = value
    }

    /**
     * @param value <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
     */
    @JvmName("jcdlfvqtiockmjyk")
    public suspend fun requireHttps(`value`: Output<Boolean>) {
        this.requireHttps = value
    }

    /**
     * @param value The configuration settings of the paths HTTP requests.
     */
    @JvmName("pyndhwaootrsjeox")
    public suspend fun routes(`value`: Output<HttpSettingsRoutesArgs>) {
        this.routes = value
    }

    /**
     * @param value The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("hkbavxluvxrklwtp")
    public suspend fun forwardProxy(`value`: ForwardProxyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.forwardProxy = mapped
    }

    /**
     * @param argument The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("tvtwtuoypmoggtxy")
    public suspend fun forwardProxy(argument: suspend ForwardProxyArgsBuilder.() -> Unit) {
        val toBeMapped = ForwardProxyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.forwardProxy = mapped
    }

    /**
     * @param value <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
     */
    @JvmName("gotswhvcaeopvkgs")
    public suspend fun requireHttps(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requireHttps = mapped
    }

    /**
     * @param value The configuration settings of the paths HTTP requests.
     */
    @JvmName("shncdpduydngaekd")
    public suspend fun routes(`value`: HttpSettingsRoutesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.routes = mapped
    }

    /**
     * @param argument The configuration settings of the paths HTTP requests.
     */
    @JvmName("tuidadsesvusjjcd")
    public suspend fun routes(argument: suspend HttpSettingsRoutesArgsBuilder.() -> Unit) {
        val toBeMapped = HttpSettingsRoutesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.routes = mapped
    }

    internal fun build(): HttpSettingsArgs = HttpSettingsArgs(
        forwardProxy = forwardProxy,
        requireHttps = requireHttps,
        routes = routes,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HttpSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HttpSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The configuration settings of the HTTP requests for authentication and authorization requests made against ContainerApp Service Authentication/Authorization.
 * @property forwardProxy The configuration settings of a forward proxy used to make the requests.
 * @property requireHttps <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
 * @property routes The configuration settings of the paths HTTP requests.
 */
public data class HttpSettingsArgs(
    public val forwardProxy: Output<ForwardProxyArgs>? = null,
    public val requireHttps: Output<Boolean>? = null,
    public val routes: Output<HttpSettingsRoutesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HttpSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HttpSettingsArgs =
        com.pulumi.azurenative.app.inputs.HttpSettingsArgs.builder()
            .forwardProxy(forwardProxy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .requireHttps(requireHttps?.applyValue({ args0 -> args0 }))
            .routes(routes?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [HttpSettingsArgs].
 */
@PulumiTagMarker
public class HttpSettingsArgsBuilder internal constructor() {
    private var forwardProxy: Output<ForwardProxyArgs>? = null

    private var requireHttps: Output<Boolean>? = null

    private var routes: Output<HttpSettingsRoutesArgs>? = null

    /**
     * @param value The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("ocufycubfkxaqbag")
    public suspend fun forwardProxy(`value`: Output<ForwardProxyArgs>) {
        this.forwardProxy = value
    }

    /**
     * @param value <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
     */
    @JvmName("byhrvccjefysrrwq")
    public suspend fun requireHttps(`value`: Output<Boolean>) {
        this.requireHttps = value
    }

    /**
     * @param value The configuration settings of the paths HTTP requests.
     */
    @JvmName("prxhtlpehhogdkbq")
    public suspend fun routes(`value`: Output<HttpSettingsRoutesArgs>) {
        this.routes = value
    }

    /**
     * @param value The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("wyahcdbqmpmdpqxp")
    public suspend fun forwardProxy(`value`: ForwardProxyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.forwardProxy = mapped
    }

    /**
     * @param argument The configuration settings of a forward proxy used to make the requests.
     */
    @JvmName("bdqwrietjvikwlmr")
    public suspend fun forwardProxy(argument: suspend ForwardProxyArgsBuilder.() -> Unit) {
        val toBeMapped = ForwardProxyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.forwardProxy = mapped
    }

    /**
     * @param value <code>false</code> if the authentication/authorization responses not having the HTTPS scheme are permissible; otherwise, <code>true</code>.
     */
    @JvmName("axtuwwxsmhmddksh")
    public suspend fun requireHttps(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requireHttps = mapped
    }

    /**
     * @param value The configuration settings of the paths HTTP requests.
     */
    @JvmName("vrghayckyqljjgdh")
    public suspend fun routes(`value`: HttpSettingsRoutesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.routes = mapped
    }

    /**
     * @param argument The configuration settings of the paths HTTP requests.
     */
    @JvmName("aovfjcdmgbnqfbgc")
    public suspend fun routes(argument: suspend HttpSettingsRoutesArgsBuilder.() -> Unit) {
        val toBeMapped = HttpSettingsRoutesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.routes = mapped
    }

    internal fun build(): HttpSettingsArgs = HttpSettingsArgs(
        forwardProxy = forwardProxy,
        requireHttps = requireHttps,
        routes = routes,
    )
}
